#
# spec file for package lua-luaposix
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define flavor lua54%{nil}
%define mod_name luaposix
%if "%{flavor}" == ""
Name:           lua-%{mod_name}
ExclusiveArch:  do_not_build
%else
Name:           %{flavor}-%{mod_name}
%endif
Version:        35.1
Release:        2.5
Summary:        POSIX library for Lua
License:        MIT
Group:          Development/Libraries/Other
URL:            https://github.com/luaposix/luaposix
Source0:        https://github.com/luaposix/luaposix/archive/v%{version}/%{mod_name}-%{version}.tar.gz
BuildRequires:  lua-macros
BuildRequires:  %{flavor}-devel
BuildRequires:  ncurses-devel
BuildRequires:  perl
Requires:       %{flavor}
%lua_provides

%description
This is a POSIX library for Lua which provides access to many POSIX features
to Lua programs.

%package -n %{mod_name}-doc
Summary:        Documentation on luaposix
Group:          Documentation/HTML
BuildArch:      noarch

%description -n %{mod_name}-doc
This package contains the documentation for %{flavor}-luaposix.

%prep
%autosetup -n luaposix-%{version}

%build
# avoid setting USER tag
export USER=""
build-aux/luke PREFIX=%{_prefix} all

%install
build-aux/luke PREFIX=%{buildroot}%{_prefix} INST_LIBDIR=%{buildroot}%{lua_archdir} \
    INST_LUADIR=%{buildroot}%{lua_noarchdir} install

%files
%doc README.md NEWS.md AUTHORS
%license LICENSE
%{lua_archdir}/posix
%{lua_noarchdir}/posix

# Only produce docs during one flavor to avoid duplicate binary.
%ifluadefault
%files -n %{mod_name}-doc
%doc doc/*
%endif

%changelog
* Wed Jan 25 2023 Michal Suchanek <msuchanek@suse.de>
- Fix missing dependency on lua-macros (boo#1205612)
* Sat Dec 18 2021 Callum Farmer <gmbr3@opensuse.org>
- Update to version 35.1:
  * Support AF_PACKET socket family, where available.
  * Support SIGINFO, SIGWINCH and SA_RESTART, where available.
  * Documentation cleanups
- avoid setting build USER tag
- Use %%ifluadefault
- Clean spec file
* Wed Jan 27 2021 Callum Farmer <gmbr3@opensuse.org>
- Use %%lua_provides macro
* Sun Jul 12 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Update to version 35.0
  * Initial support for Lua 5.4
  * Internally, we use our own bitwise operation wrapper functions
    rather than bit32 where possible. This means bitwise operations
    when running under Lua 5.3+ work on 64bit integers.
* Mon Jul  6 2020 Matej Cepl <mcepl@suse.com>
- Add lua54 as new build target
* Fri Aug 30 2019 Ana Guerrero Lopez <aguerrero@suse.com>
- New version 34.1.1, please read NEWS.md for changes (jsc#SLE-8509)
- Remove patch, merged upstream:
  * maint-sync-luke-with-upstream.patch
- Add %%license
* Thu Apr 26 2018 jberry@suse.com
- Only produce docs during one flavor to avoid duplicate binary.
* Mon Oct 30 2017 jmatejek@suse.com
- do not build for Lua 5.2
* Thu Aug 10 2017 eich@suse.com
- Updating to version 3.4:
  * Incompatible Changes  Incompatible Changes
    posix.syslog constants LOG_AUTHPRIV, LOG_FTP and LOG_SYSLOG are no longer
    documented, and only defined when supported by the host C library. They are
    not part of the POSIX API, and prevented compilation of luaposix on AIX and
    Solaris.
    getopt.getopt was a binding to the GNU getopt_long extension, which is not
    a POSIX API, and prevents luaposix from compiling on hosts that do not
    provide the extended API. Instead we now correctly bind POSIX getopt(3) in
    posix.unistd.
  * New Features
    Replaced all Autotools and supporting Slingshot code with new Lua- based
    build-aux/luke and lukefile describing how to compile and install
    everything. Building with LuaRocks now leverages this too.
    New posix.sys.socket.getsockopt and posix.sys.socket.getpeername bindings.
    New posix.sys.msg.msgctl binding, and posix.sys.msg.IPC_RMID,
    posix.sys.msg.IPC_SET and posix.sys.msg.IPC_STAT constants to use with it.
    New posix.unistd.ftruncate and posix.unistd.truncate bindings.
    posix.fcntl.fcntl now accepts undocumented posix.fcntl.O_TMPFILE value
    where supported by the host C library.
  * Bugs Fixed
    posix.unistd.ttyname now returns an error message in addition to nil when
    it fails.
  * maint-sync-luke-with-upstream.patch:
    Backported from upstream to make this build and install with the 'luke'
    version included.
* Thu Aug 10 2017 eich@suse.com
- Fix provides/obsoletes for the old package name.
* Thu Jul 13 2017 tchvatal@suse.com
- Put documentation on %%_docdir/%%name not just %%_docdir
* Thu Jul 13 2017 tchvatal@suse.com
- Switch to multibuild build
- Update to 33.3.1:
  * Various lua5.3 fixes
- Drop patch install_path.patch
* Wed Jan  4 2017 eich@suse.com
- Replaced 'makeinstall' by 'make_install'.
- Removed %%clean section.
- Replaced Documentation/http by Documentation/HTML.
* Mon Oct 17 2016 eich@suse.com
- Setting 'download_files' service to mode='localonly'
  and adding source tarball. (Required for Factory).
* Tue Oct 11 2016 eich@suse.com
- Initial version of lua-luaposix: 33.2.1.
